Module: MatrixCreator::Everloop::Color

Defined in:
lib/matrix_creator/everloop/color.rb

Overview

Contains the constants to be used for RGB+W Color values

Constant Summary collapse

WHITE =

Contains the hash values for the color white

{ r: 0, g: 0, b: 0, w: 10 }.freeze
RED =

Contains the hash values for the color red

{ r: 10, g: 0, b: 0, w: 0 }.freeze
ORANGE =

Contains the hash values for the color orange

{ r: 10, g: 2, b: 0, w: 0 }.freeze
YELLOW =

Contains the hash values for the color yellow

{ r: 10, g: 5, b: 0, w: 0 }.freeze
SPRING_GREEN =

Contains the hash values for the color spring green

{ r: 8, g: 10, b: 0, w: 0 }.freeze
GREEN =

Contains the hash values for the color green

{ r: 0, g: 10, b: 0, w: 0 }.freeze
TURQUOISE =

Contains the hash values for the color turquoise

{ r: 0, g: 10, b: 2, w: 0 }.freeze
CYAN =

Contains the hash values for the color cyan

{ r: 0, g: 10, b: 10, w: 0 }.freeze
OCEAN =

Contains the hash values for the color ocean

{ r: 0, g: 6, b: 10, w: 0 }.freeze
BLUE =

Contains the hash values for the color blue

{ r: 0, g: 0, b: 10, w: 0 }.freeze
VIOLET =

Contains the hash values for the color violet

{ r: 4, g: 0, b: 10, w: 0 }.freeze
MAGENTA =

Contains the hash values for the color magenta

{ r: 10, g: 0, b: 10, w: 0 }.freeze
RASPBERRY =

Contains the hash values for the color raspberry

{ r: 10, g: 0, b: 3, w: 0 }.freeze
OFF =

Contains the hash values to turn off the Led

{ r: 0, g: 0, b: 0, w: 0 }.freeze